==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/gamekit/GKVoiceChatClient.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.gamekit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
/*</imports>*/

/*<javadoc>*/

/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/GKVoiceChatClient/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<methods>*/
    @Method(selector = "voiceChatService:sendData:toParticipantID:")
    void sendData(GKVoiceChatService voiceChatService, NSData data, String participantID);
    @Method(selector = "participantID")
    String getParticipantID();
    @Method(selector = "voiceChatService:sendRealTimeData:toParticipantID:")
    void sendRealTimeData(GKVoiceChatService voiceChatService, NSData data, String participantID);
    @Method(selector = "voiceChatService:didStartWithParticipantID:")
    void didStart(GKVoiceChatService voiceChatService, String participantID);
    @Method(selector = "voiceChatService:didNotStartWithParticipantID:error:")
    void didNotStart(GKVoiceChatService voiceChatService, String participantID, NSError error);
    @Method(selector = "voiceChatService:didStopWithParticipantID:error:")
    void didStop(GKVoiceChatService voiceChatService, String participantID, NSError error);
    @Method(selector = "voiceChatService:didReceiveInvitationFromParticipantID:callID:")
    void didReceiveInvitation(GKVoiceChatService voiceChatService, String participantID, @MachineSizedSInt long callID);
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}

==> robovm-cocoatouch-2.3.16-sources.jar: org/robovm/apple/gamekit/GKVoiceChatClient.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.gamekit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.uikit.*;
import org.robovm.apple.coregraphics.*;
/*</imports>*/

/*<javadoc>*/
/**
 * @deprecated Deprecated in iOS 7.0. Use GKVoiceChat instead
 */
/*</javadoc>*/
/*<annotations>*/@Deprecated/*</annotations>*/
/*<visibility>*/public/*</visibility>*/ interface /*<name>*/GKVoiceChatClient/*</name>*/ 
    /*<implements>*/extends NSObjectProtocol/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<methods>*/
    @Method(selector = "voiceChatService:sendData:toParticipantID:")
    void sendData(GKVoiceChatService voiceChatService, NSData data, String participantID);
    @Method(selector = "participantID")
    String getParticipantID();
    @Method(selector = "voiceChatService:sendRealTimeData:toParticipantID:")
    void sendRealTimeData(GKVoiceChatService voiceChatService, NSData data, String participantID);
    @Method(selector = "voiceChatService:didStartWithParticipantID:")
    void didStart(GKVoiceChatService voiceChatService, String participantID);
    @Method(selector = "voiceChatService:didNotStartWithParticipantID:error:")
    void didNotStart(GKVoiceChatService voiceChatService, String participantID, NSError error);
    @Method(selector = "voiceChatService:didStopWithParticipantID:error:")
    void didStop(GKVoiceChatService voiceChatService, String participantID, NSError error);
    @Method(selector = "voiceChatService:didReceiveInvitationFromParticipantID:callID:")
    void didReceiveInvitation(GKVoiceChatService voiceChatService, String participantID, @MachineSizedSInt long callID);
    /*</methods>*/
    /*<adapter>*/
    /*</adapter>*/
}
